@@ -1,9 +1,7 @@
 /*
-(C) 1998 Patrick Lambert <drow@fastethernet.net>
+(C) 1998-99 Patrick Lambert <drow@fastethernet.net>
 
-This program is free software. You can use, distribute and modify it if
-you let this legal note in all future versions, and if the program made
-stays under free software. (see sscript.doc)
+This program is under the GPL
 
 This program is distributed without ANY WARRANTY, without even the
 implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
@@ -16,6 +14,8 @@ http://devplanet.fastethernet.net/sscript.html
 #include "config.h"
 #include "sscript.h"
 
+#include <string.h>
+
 #ifdef GUI
 #ifdef GTK
 #include <gtk/gtk.h>
@@ -32,6 +32,20 @@ GdkPixmap *pixmap;
 GdkBitmap *mask;
 GtkStyle *style;
 
+static gushort convert_color(unsigned c)
+{
+ if (c==0) return(0);
+ c *= 257;
+ return(c > 0xffff)? 0xffff : c;
+}
+
+void extract_color(GdkColor *color, unsigned red, unsigned green, unsigned blue)
+{
+ color->red = convert_color(red);
+ color->green = convert_color(green);
+ color->blue = convert_color(blue);
+}
+
 int GTK_destroy_widget(GtkWidget *widget, GtkWidget *entry)
 {
  gtk_widget_destroy(widget);
@@ -85,13 +99,13 @@ int GTK_startup_quit(GtkWidget *widget, GtkWidget *entry)
  return(FALSE);  
 }
 
-int GTK_composer_clear(GtkWidget *widget, GtkWidget *entry)
+void GTK_composer_clear(GtkWidget *widget, GtkWidget *entry)
 {
  gtk_text_set_point(GTK_TEXT(text), 0);
  gtk_text_forward_delete(GTK_TEXT(text), gtk_text_get_length(GTK_TEXT(text)));
 }
 
-int GTK_composer_cmd_ok(GtkWidget *widget, GtkWidget *entry)
+void GTK_composer_cmd_ok(GtkWidget *widget, GtkWidget *entry)
 {
  help(3,2,NULL,gtk_entry_get_text(GTK_ENTRY(entry_box)));
  GTK_destroy_widget(widget, entry);
@@ -197,7 +211,7 @@ int GTK_composer_cmd(GtkWidget *widget, GtkWidget *entry)
 }
 
 
-int GTK_composer_yes(GtkWidget *widget, GtkWidget *entry)
+void GTK_composer_yes(GtkWidget *widget, GtkWidget *entry)
 {
  gtk_widget_destroy(widget);
  gtk_main_quit();
@@ -205,7 +219,7 @@ int GTK_composer_yes(GtkWidget *widget, GtkWidget *entry)
  exit(0);
 }
 
-int GTK_composer_about(GtkWidget *widget, GtkWidget *entry)
+void GTK_composer_about(GtkWidget *widget, GtkWidget *entry)
 {
  GtkWidget *separator;
  window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -246,17 +260,17 @@ int GTK_composer_about(GtkWidget *widget, GtkWidget *entry)
  gtk_main();
 }
 
-int GTK_composer_help(GtkWidget *widget, GtkWidget *entry)
+void GTK_composer_help(GtkWidget *widget, GtkWidget *entry)
 {
  help(3,2,NULL,"composer");
 }
 
-int GTK_composer_lib(GtkWidget *widget, GtkWidget *entry)
+void GTK_composer_lib(GtkWidget *widget, GtkWidget *entry)
 {
  help(3,2,NULL,"libraries");
 }
 
-int GTK_composer_help_old(GtkWidget *widget, GtkWidget *entry)
+void GTK_composer_help_old(GtkWidget *widget, GtkWidget *entry)
 {
  GtkWidget *separator;
  window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -295,7 +309,7 @@ int GTK_composer_help_old(GtkWidget *widget, GtkWidget *entry)
  gtk_main();
 }
 
-int GTK_composer_quit(GtkWidget *widget, GtkWidget *entry)
+void GTK_composer_quit(GtkWidget *widget, GtkWidget *entry)
 {
  GtkWidget *separator;
  window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -630,7 +644,7 @@ int GTK_choice_box_10(GtkWidget *widget, GtkWidget *entry)
  return(FALSE);
 }
 
-int msgbox(char *type, char *string, int len)
+void msgbox(char *type, char *string, int len)
 {
  window = gtk_dialog_new ();
  if(strcasecmp(type,"header"))
@@ -1000,7 +1014,7 @@ int view_n_query(char *file, char *string, int argc, char *argv[])
 
 int choicebox(int argc1, char *argv1[])
 {
- int i,j;
+ int i;
  window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_signal_connect (GTK_OBJECT (window), "destroy",
   GTK_SIGNAL_FUNC(GTK_destroy_widget), &window);
@@ -1881,20 +1895,6 @@ int gui_help(char *string, int argc, char *argv[])
  return(0);
 }
 
-static gushort convert_color(unsigned c)
-{
- if (c==0) return(0);
- c *= 257;
- return(c > 0xffff)? 0xffff : c;
-}
-
-int extract_color(GdkColor *color, unsigned red, unsigned green, unsigned blue)
-{
- color->red = convert_color(red);
- color->green = convert_color(green);
- color->blue = convert_color(blue);
-}
-
 int custom_callbacks(gint choice, GtkWidget *entry)
 {
  FILE *fpg;
@@ -2095,6 +2095,7 @@ int custom_gui(char in[1024][512])
   gtk_main();
   return(0);  
  }
+ return(0);
 }
 #endif /* gtk */
 #endif /* gui */
