@@ -1,9 +1,7 @@
 /*
-(C) 1998 Patrick Lambert <drow@fastethernet.net>
+(C) 1998-99 Patrick Lambert <drow@fastethernet.net>
 
-This program is free software. You can use, distribute and modify it if
-you let this legal note in all future versions, and if the program made
-stays under free software. (see sscript.doc)
+This program is under the GPL
 
 This program is distributed without ANY WARRANTY, without even the
 implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR   
