@@ -1,9 +1,7 @@
 /*
-(C) 1998 Patrick Lambert <drow@fastethernet.net>
+(C) 1998-99 Patrick Lambert <drow@fastethernet.net>
 
-This program is free software. You can use, distribute and modify it if
-you let this legal note in all future versions, and if the program made
-stays under free software. (see sscript.doc)
+This program is under the GPL
 
 This program is distributed without ANY WARRANTY, without even the
 implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
@@ -50,15 +48,12 @@ int unzip_file(char *i, char *o)
  gzFile gfd;
  FILE *fd;
  char *data;
- int len = 1000000;
- data = malloc(1000000);
- bzero(data, 1000000);
+ data = malloc(1);
  gfd = gzopen(i, "rb");
- if(gfd==NULL) { lasterror=124; return -1; }
- gzread(gfd, data, len);
- gzclose(gfd);
  fd = fopen(o, "w");
- fputs(data,fd);
+ while(gzread(gfd, data, 1)>0)
+ fwrite(data, 1, 1, fd);
+ gzclose(gfd);
  if(fd!=NULL) fclose(fd);
  free(data);
 }
@@ -68,17 +63,11 @@ int zip_file(char *i, char *o)
  gzFile gfd;
  FILE *fd;
  char *data;
- char string[512];
- int len;
- data = malloc(1000000);
- bzero(data, 1000000);
+ data = malloc(1);
  fd = fopen(i, "r");
- while(fgets(string,512,fd)!=NULL) strcat(data,string);
- if(fd!=NULL) fclose(fd);
  gfd = gzopen(o, "wb");
- if(gfd==NULL) { lasterror=124; return -1; }
- len = strlen(data)+1;
- gzwrite(gfd, data, len);
+ while(fread(data, 1, 1, fd)>0)
+ gzwrite(gfd, data, 1);
  gzclose(gfd);
  free(data);
 }
